@@ -1,4 +1,11 @@
 """ This file deals with modelling functions related to statistics such as:
     1. Auto-ARIMA model
     2. Regression models such as Ridge/Lasso/OLS
-"""
\ No newline at end of file
+"""
+
+from quant_risk.models import *
+
+__all__ = [
+    'regression',
+    'time_series',
+]
\ No newline at end of file
